@@ -1,6 +1,6 @@
 # flake8:noqa:F401
 from .download import BINARY_DIR, BINARY_PATH, download_gocq
-from .manager import ProcessesManager, ACCOUNTS_SAVE_PATH
+from .manager import ACCOUNTS_SAVE_PATH, ProcessesManager, kill_duplicated_processes
 from .models import (
     ProcessAccount,
     ProcessInfo,
